==> haskell-ap-normalize-0.1.0.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ap-normalize
version:              0.1.0.1
visibility:           public
id:                   ap-normalize-0.1.0.1-9HQrlDTZ9EHGRh8QCN8Gop
key:                  ap-normalize-0.1.0.1-9HQrlDTZ9EHGRh8QCN8Gop
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  4e4c17884a4d4ac557cca387717ed4da
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ap-normalize
hs-libraries:         HSap-normalize-0.1.0.1-9HQrlDTZ9EHGRh8QCN8Gop
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ap-normalize-0.1.0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ap-normalize
version:              0.1.0.1
visibility:           public
id:                   ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv
key:                  ap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  4fe0b579cee17d6ea476bf4f01e68209
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ap-normalize-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ap-normalize
hs-libraries:         HSap-normalize-0.1.0.1-2OIZezFTFdID4zyW3I24kv
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
